@@ -1,7 +1,7 @@
 import argparse
 import os
 
-from .data import KindsOfDataReader
+from .cache import KindsOfCache
 from .tap import KindsOfSource
 
 
@@ -10,8 +10,8 @@ def parse_kind(args):
     kindParser.add_argument('--kind', type=str, default=os.environ.get('PIPELINE', None),
                             choices=KindsOfSource(),
                             help='pipeline kind, can be {}'.format(','.join(KindsOfSource())))
-    kindParser.add_argument('--dataKind', type=str, default=os.environ.get('DATAKIND', None),
-                            choices=KindsOfDataReader(),
-                            help='data kind, can be {}'.format(','.join(KindsOfDataReader())))
+    kindParser.add_argument('--cacheKind', type=str, default=os.environ.get('CACHEKIND', None),
+                            choices=KindsOfCache(),
+                            help='cache kind, can be {}'.format(','.join(KindsOfCache())))
     known, extras = kindParser.parse_known_args(args)
     return known, extras
